#! /usr/bin/csh 

#-----------------------------------------------------------------------
## IBM
##------------
##
## This is an example script to build and run the default CAM configuration
## on an IBM SP.  The default configuration is T42L26, Eulerian dynamics,
## CLM2 land model, and CSIM4 ice model.
##
## Setting LoadLeveler options for batch queue submission.
## @ class is the queue in which to run the job.
##     To see a list of available queues, type "llclass" interactively.
## @ node is the number of nodes. @tasks_per_node should be set to 1 because
##     of the hybrid OpenMP/MPI configuration of CAM.  The number of nodes should
##     be a power of 2, up to a max of 16 for T42.
## @ output and @error are the names of file written to the directory from
##     which the script is submitted containing STDOUT and STDERR respectively
## @ job_type = parallel declares that multiple nodes will be used.
## @ network.MPI: Has to do with network connection between nodes.  Best to leave alone.
## @ node_usage = not_shared acquires dedicated access to nodes for the job.
## @ queue tells load leveler to submit the job

#@ job_name       = cam31_ser_fv64
#@ class          = debug
##@ account_no     = mpccc
#@ node           = 16 
#@ total_tasks    = 64
#@ output         = cam31_ser_fv64.out
#@ error          = cam31_ser_fv64.err
#@ wall_clock_limit = 00:30:00
#@ job_type       = parallel
#@ network.MPI    = csss,not_shared,us
#@ node_usage     = not_shared
#@ environment    = COPY_ALL
#@ checkpoint     = no
#@ queue

## POE Environment.  Set these for interactive jobs.  They're ignored by LoadLeveler
## MP_NODES is the number of nodes.  The number chosen should be a power of 2, up to a max of 16 for T42.
#setenv MP_NODES 2
setenv MP_TASKS_PER_NODE 1
setenv MP_EUILIB us
setenv MP_RMPOOL 1
# TH:  bug fix suggested by Brian Eaton  1/24/03
#setenv MP_PROCS 28

# must be set equal to (CPUs-per-node / tasks_per_node)
setenv OMP_NUM_THREADS 1

## suggestion from Jim Edwards to reintroduce XLSMPOPTS on 11/13/03
setenv XLSMPOPTS "stack=256000000"
setenv AIXTHREAD_SCOPE S
setenv MALLOCMULTIHEAP true
setenv OMP_DYNAMIC false
## Do our best to get sufficient stack memory
limit stacksize unlimited

## netCDF stuff
setenv INC_NETCDF /usr/common/usg/netcdf_64/default/include
setenv LIB_NETCDF /usr/common/usg/netcdf_64/default/lib
  
# you need to set these if necessary
#setenv INC_MPI 
#setenv LIB_MPI 

## SETTING YOUR RUNNING DIRECTORY
##YOU HAVE TO CHANGE THE FOLLOWING LINE FOR THE APPROPRIATE camroot PATH BEFORE SUBMITTING THE JOB
set SCRATCH = $current
## ROOT OF CAM DISTRIBUTION - probably needs to be customized.
## Contains the source code for the CAM distribution.
## (the root directory contains the subdirectory "models")
set camroot      = $SCRATCH/CAMMODELS/cam3.1

## ROOT OF CAM DATA DISTRIBUTION - needs to be customized unless running at NCAR.
## Contains the initial and boundary data for the CAM distribution.
## (the root directory contains the subdirectories "atm" and "lnd")
set caminput  =  $SCRATCH/input

## Default namelist settings:
## $case is the case identifier for this run. It will be placed in the namelist.
## $runtype is the run type: initial, restart, or branch.
## $nelapse is the number of timesteps to integrate, or number of days if negative.
set case         = benchmark_3.1_ser
set output       = job64
set runtype      = initial

## $wrkdir is a working directory where the model will be built and run.
## $blddir is the directory where model will be compiled.
## $rundir is the directory where the model will be run.
## $cfgdir is the directory containing the CAM configuration scripts.
## $jobdir is the directory containing the CAM job scripts and namelists.
set wrkdir       = $SCRATCH
set blddir       = $wrkdir/$case/bld
set rundir       = $wrkdir/$case/$output
set cfgdir       = $camroot/models/atm/cam/bld
set jobdir       = $wrkdir/run_3.1_ser
set pnfdir	 = $SCRATCH/PNETCDF64

## Ensure that run and build directories exist
mkdir -p $blddir                || echo "cannot create $blddir" && exit 1
mkdir -p $rundir                || echo "cannot create $rundir" && exit 1

## If an executable doesn't exist, build one.
if ( ! -x $blddir/cam ) then
    cd $blddir                  || echo "cd $blddir failed" && exit 1
    $cfgdir/configure -dyn fv -res 0.5x0.625 -spmd -nosmp || echo "configure failed" && exit 1
    echo "building CAM in $blddir ..."
    rm -f Depends
    gmake -j4 >&! MAKE.out      || echo "CAM build failed: see $blddir/MAKE.out" && exit 1
    echo CAM is built successfully!
endif

## Create the namelist
cd $jobdir
if ( ! -f namelistq64 ) then
    echo building namelistq64
    build-namelistq64.csh || echo "build-namelist failed" && exit 1
endif


## If you build INTERACTIVELY only:  
## exit here - uncomment statement 'exit 0' below.

# exit 0

## ****** If you build and run IN A SINGLE STEP,  comment above line 
## COMMENT OUT THE FOLLOWING LINE IN SEABORG BECAUSE IT HAS A bUG
#module load ipm

## Run CAM
cd $rundir                      || echo "cd $rundir failed" && exit 1
echo "running CAM in $rundir"
echo "jobdir is $jobdir"
echo "blddir is $blddir"

poe $blddir/cam < $jobdir/namelistq64 > &! atm.log.$$     || echo "CAM run failed" && exit 1

#mkdir -p 5days
#mv spmd* 5days/.
#mv timing* 5days/.

exit 0
